==> clone-workspace-scm-0.1-sources.jar: hudson/plugins/cloneworkspace/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.cloneworkspace;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Archiving workspace
     * 
     */
    public static String CloneWorkspacePublisher_ArchivingWorkspace() {
        return holder.format("CloneWorkspacePublisher.ArchivingWorkspace");
    }

    /**
     * Archiving workspace
     * 
     */
    public static Localizable _CloneWorkspacePublisher_ArchivingWorkspace() {
        return new Localizable(holder, "CloneWorkspacePublisher.ArchivingWorkspace");
    }

    /**
     * There''s no qualifying build matching the criteria ''{0}'' in {1}
     * 
     */
    public static String CloneWorkspaceSCM_NoBuild(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoBuild", arg1, arg2);
    }

    /**
     * There''s no qualifying build matching the criteria ''{0}'' in {1}
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoBuild(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoBuild", arg1, arg2);
    }

    /**
     * {0}''s most recent build matching the criteria ''{1}''  doesn''t have a workspace snapshot attached.
     * Please run another build in {0} to get the workspace snapshot generated and attached.
     * 
     */
    public static String CloneWorkspaceSCM_NoWorkspace(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoWorkspace", arg1, arg2);
    }

    /**
     * {0}''s most recent build matching the criteria ''{1}''  doesn''t have a workspace snapshot attached.
     * Please run another build in {0} to get the workspace snapshot generated and attached.
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoWorkspace(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoWorkspace", arg1, arg2);
    }

    /**
     * No permalink relating to the criteria ''{0}'' exists for {1}
     * 
     */
    public static String CloneWorkspaceSCM_NoSuchCriteria(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoSuchCriteria", arg1, arg2);
    }

    /**
     * No permalink relating to the criteria ''{0}'' exists for {1}
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoSuchCriteria(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoSuchCriteria", arg1, arg2);
    }

    /**
     * Build does not meet criteria for workspace archiving - result is not at least {0}.
     * 
     */
    public static String CloneWorkspacePublisher_CriteriaNotMet(Object arg1) {
        return holder.format("CloneWorkspacePublisher.CriteriaNotMet", arg1);
    }

    /**
     * Build does not meet criteria for workspace archiving - result is not at least {0}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_CriteriaNotMet(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.CriteriaNotMet", arg1);
    }

    /**
     * Archive workspace
     * 
     */
    public static String CloneWorkspacePublisher_DisplayName() {
        return holder.format("CloneWorkspacePublisher.DisplayName");
    }

    /**
     * Archive workspace
     * 
     */
    public static Localizable _CloneWorkspacePublisher_DisplayName() {
        return new Localizable(holder, "CloneWorkspacePublisher.DisplayName");
    }

    /**
     * {0} isn''t a job that has a workspace.
     * 
     */
    public static String CloneWorkspaceSCM_IncorrectJobType(Object arg1) {
        return holder.format("CloneWorkspaceSCM.IncorrectJobType", arg1);
    }

    /**
     * {0} isn''t a job that has a workspace.
     * 
     */
    public static Localizable _CloneWorkspaceSCM_IncorrectJobType(Object arg1) {
        return new Localizable(holder, "CloneWorkspaceSCM.IncorrectJobType", arg1);
    }

    /**
     * Deleting old workspace snapshot from {0}.
     * 
     */
    public static String CloneWorkspacePublisher_DeletingOld(Object arg1) {
        return holder.format("CloneWorkspacePublisher.DeletingOld", arg1);
    }

    /**
     * Deleting old workspace snapshot from {0}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_DeletingOld(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.DeletingOld", arg1);
    }

    /**
     * Failed to archive workspace with pattern {0}
     * 
     */
    public static String CloneWorkspacePublisher_FailedToArchive(Object arg1) {
        return holder.format("CloneWorkspacePublisher.FailedToArchive", arg1);
    }

    /**
     * Failed to archive workspace with pattern {0}
     * 
     */
    public static Localizable _CloneWorkspacePublisher_FailedToArchive(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.FailedToArchive", arg1);
    }

    /**
     * No files were found in the workspace matching the file pattern "{0}". Possible configuration error: {1}.
     * 
     */
    public static String CloneWorkspacePublisher_NoMatchFound(Object arg1, Object arg2) {
        return holder.format("CloneWorkspacePublisher.NoMatchFound", arg1, arg2);
    }

    /**
     * No files were found in the workspace matching the file pattern "{0}". Possible configuration error: {1}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_NoMatchFound(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspacePublisher.NoMatchFound", arg1, arg2);
    }

    /**
     * No such job ''{0}'' exists. Perhaps you meant ''{1}''?
     * 
     */
    public static String CloneWorkspaceSCM_NoSuchJob(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoSuchJob", arg1, arg2);
    }

    /**
     * No such job ''{0}'' exists. Perhaps you meant ''{1}''?
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoSuchJob(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoSuchJob", arg1, arg2);
    }

}

==> clone-workspace-scm-0.2-sources.jar: hudson/plugins/cloneworkspace/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.cloneworkspace;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Archiving workspace
     * 
     */
    public static String CloneWorkspacePublisher_ArchivingWorkspace() {
        return holder.format("CloneWorkspacePublisher.ArchivingWorkspace");
    }

    /**
     * Archiving workspace
     * 
     */
    public static Localizable _CloneWorkspacePublisher_ArchivingWorkspace() {
        return new Localizable(holder, "CloneWorkspacePublisher.ArchivingWorkspace");
    }

    /**
     * There''s no qualifying build matching the criteria ''{0}'' in {1}
     * 
     */
    public static String CloneWorkspaceSCM_NoBuild(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoBuild", arg1, arg2);
    }

    /**
     * There''s no qualifying build matching the criteria ''{0}'' in {1}
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoBuild(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoBuild", arg1, arg2);
    }

    /**
     * Clone Workspace
     * 
     */
    public static String CloneWorkspaceSCM_DisplayName() {
        return holder.format("CloneWorkspaceSCM.DisplayName");
    }

    /**
     * Clone Workspace
     * 
     */
    public static Localizable _CloneWorkspaceSCM_DisplayName() {
        return new Localizable(holder, "CloneWorkspaceSCM.DisplayName");
    }

    /**
     * {0}''s most recent build matching the criteria ''{1}''  doesn''t have a workspace snapshot attached.
     * Please run another build in {0} to get the workspace snapshot generated and attached.
     * 
     */
    public static String CloneWorkspaceSCM_NoWorkspace(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoWorkspace", arg1, arg2);
    }

    /**
     * {0}''s most recent build matching the criteria ''{1}''  doesn''t have a workspace snapshot attached.
     * Please run another build in {0} to get the workspace snapshot generated and attached.
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoWorkspace(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoWorkspace", arg1, arg2);
    }

    /**
     * No permalink relating to the criteria ''{0}'' exists for {1}
     * 
     */
    public static String CloneWorkspaceSCM_NoSuchCriteria(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoSuchCriteria", arg1, arg2);
    }

    /**
     * No permalink relating to the criteria ''{0}'' exists for {1}
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoSuchCriteria(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoSuchCriteria", arg1, arg2);
    }

    /**
     * Build does not meet criteria for workspace archiving - result is not at least {0}.
     * 
     */
    public static String CloneWorkspacePublisher_CriteriaNotMet(Object arg1) {
        return holder.format("CloneWorkspacePublisher.CriteriaNotMet", arg1);
    }

    /**
     * Build does not meet criteria for workspace archiving - result is not at least {0}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_CriteriaNotMet(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.CriteriaNotMet", arg1);
    }

    /**
     * Archive for Clone Workspace SCM
     * 
     */
    public static String CloneWorkspacePublisher_DisplayName() {
        return holder.format("CloneWorkspacePublisher.DisplayName");
    }

    /**
     * Archive for Clone Workspace SCM
     * 
     */
    public static Localizable _CloneWorkspacePublisher_DisplayName() {
        return new Localizable(holder, "CloneWorkspacePublisher.DisplayName");
    }

    /**
     * {0} isn''t a job that has a workspace.
     * 
     */
    public static String CloneWorkspaceSCM_IncorrectJobType(Object arg1) {
        return holder.format("CloneWorkspaceSCM.IncorrectJobType", arg1);
    }

    /**
     * {0} isn''t a job that has a workspace.
     * 
     */
    public static Localizable _CloneWorkspaceSCM_IncorrectJobType(Object arg1) {
        return new Localizable(holder, "CloneWorkspaceSCM.IncorrectJobType", arg1);
    }

    /**
     * Deleting old workspace snapshot from {0}.
     * 
     */
    public static String CloneWorkspacePublisher_DeletingOld(Object arg1) {
        return holder.format("CloneWorkspacePublisher.DeletingOld", arg1);
    }

    /**
     * Deleting old workspace snapshot from {0}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_DeletingOld(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.DeletingOld", arg1);
    }

    /**
     * Failed to archive workspace with pattern {0}
     * 
     */
    public static String CloneWorkspacePublisher_FailedToArchive(Object arg1) {
        return holder.format("CloneWorkspacePublisher.FailedToArchive", arg1);
    }

    /**
     * Failed to archive workspace with pattern {0}
     * 
     */
    public static Localizable _CloneWorkspacePublisher_FailedToArchive(Object arg1) {
        return new Localizable(holder, "CloneWorkspacePublisher.FailedToArchive", arg1);
    }

    /**
     * No files were found in the workspace matching the file pattern "{0}". Possible configuration error: {1}.
     * 
     */
    public static String CloneWorkspacePublisher_NoMatchFound(Object arg1, Object arg2) {
        return holder.format("CloneWorkspacePublisher.NoMatchFound", arg1, arg2);
    }

    /**
     * No files were found in the workspace matching the file pattern "{0}". Possible configuration error: {1}.
     * 
     */
    public static Localizable _CloneWorkspacePublisher_NoMatchFound(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspacePublisher.NoMatchFound", arg1, arg2);
    }

    /**
     * No such job ''{0}'' exists. Perhaps you meant ''{1}''?
     * 
     */
    public static String CloneWorkspaceSCM_NoSuchJob(Object arg1, Object arg2) {
        return holder.format("CloneWorkspaceSCM.NoSuchJob", arg1, arg2);
    }

    /**
     * No such job ''{0}'' exists. Perhaps you meant ''{1}''?
     * 
     */
    public static Localizable _CloneWorkspaceSCM_NoSuchJob(Object arg1, Object arg2) {
        return new Localizable(holder, "CloneWorkspaceSCM.NoSuchJob", arg1, arg2);
    }

}
